function [Ran0, RanC, idxC] = vdoCacheIdx(cFs, nF0, wF, dire)
% Return frame index for filtering.
%
% Input
%   cFs     -  index of center frame, 1 x nF
%   nF      -  video length
%   wF      -  windows width, 1 | 2 | ...
%   dire    -  direction, 'left' | 'right' | 'both'
%
% Output
%   Ran0    -  range of each window in the original sequence, 3 x nF
%   RanC    -  range of each window in the cache, 3 x nF
%   idxC    -  cache position of each frame in the original sequence, 1 x nF0
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-15-2013

% dimension
nF = length(cFs);

% range
if strcmp(dire, 'left')
    Ran0 = [max(1, cFs - wF + 1); cFs; cFs];

elseif strcmp(dire, 'right')
    Ran0 = [cFs; min(nF0, cFs + wF - 1); cFs];

elseif strcmp(dire, 'both')
    wF2 = floor(wF / 2);
    Ran0 = [max(1, cFs - wF2); min(nF0, cFs + wF - wF2 - 1); cFs];

else
    error('unknow dire: %s', dire);
end

% range in the cache
RanC = mod(Ran0, wF);
RanC(RanC == 0) = wF;

% update status
idxC = mod(1 : nF0, wF);
idxC(idxC == 0) = wF;

visUpd = zeros(1, nF0);
for iF = 1 : nF
    visUpd(Ran0(1, iF) : Ran0(2, iF)) = 1;
end
idx = visUpd == 0;
idxC(idx) = -idxC(idx);
