function pFs = vdoFiltIdx(cF, wF, dire, gapF, nF)
% Return frame index for filtering.
%
% Input
%   cF      -  index of the center frame
%   wF      -  windows width, 1 | 2 | ...
%   dire    -  direction, 'left' | 'both' | 'right'
%   gapF    -  frame gap, 1 | ...
%   nF      -  number of frames in the whole sequence
%
% Output
%   pFs     -  frame index, 1 x (wF + 1)
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-22-2013

% frame index
if strcmp(dire, 'left')
    pFs = cF : -gapF : max(1, cF - wF + 1);

elseif strcmp(dire, 'right')
    pFs = cF : gapF : min(nF, cF + wF - 1);

elseif strcmp(dire, 'both')
    wF2 = floor(wF / 2);
    pFs = max(1, cF - wF2) : gapF : min(nF, cF + wF - wF2 - 1);
else
    error('unknown dire %d', dire);
end
