function Ws = vdoFiltWeiGauss(siz, pFs, sig)
% Computing Gaussian filtering weight.
%
% Input
%   siz     -  image size, [h x w]
%   pFs     -  frame index, 1 x (wF + 1)
%   sig     -  sigma
%
% Output
%   Ws      -  weight, h x w x (wF + 1)
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 06-03-2013
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-29-2013

% default parameter
if ~exist('sig', 'var')
    sig = 3;
end

% dimension
h = siz(1);
w = siz(2);
wF = length(pFs) - 1;

% weight
dts = 0 : wF;
ws = exp(- dts .^ 2 / (wF / sig + eps) ^ 2 / 2);
ws = ws ./ sum(ws);
Ws = zeros(h, w, wF + 1);
for i = 1 : wF + 1
    Ws(:, :, i) = ws(i);
end
