function D = computeHistDist(Hst, A, idx)
% Compute saliency for histogram.
%
% Input
%   Hst     -  region histogram, mSeg x nBin
%   A       -  adjacency matrix, mSeg x mSeg
%   idx     -  index of non-zero entry
%
% Output
%   D       -  histogram distance, mSeg x mSeg
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-28-2013

% dimension
mSeg = size(A, 1);

% adjust adjacency
for cSeg = 1 : mSeg
    A(cSeg, cSeg) = 0;
end

% only non-zero entry
if exist('idx', 'var') && ~isempty(idx)
    A(idx, :) = 0;
    A(:, idx) = 0;
end

% pair-wise distance
% D2 = zeros(mSeg, mSeg);
% ind = find(A);
% for c = 1 : length(ind)
%     [x, y] = ind2sub([mSeg, mSeg], ind(c));
%     D2(x, y) = histDist(Hst(x, :), Hst(y, :));
% end

D = zeros(mSeg, mSeg);
ind = find(A);
[is, js] = ind2sub([mSeg mSeg], ind);
ds = conDstHst(Hst(is, :)', Hst(js, :)');
% ds = conDstHst2(Hst(is, :)', Hst(js, :)');
D(ind) = ds;
% equal('D', D, D2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ds = conDstHst2(Hst1, Hst2)
% L2-normalized histogram distance.

[d, ~] = size(Hst1);

% normalize
len1 = sum(Hst1 .^ 2);
len2 = sum(Hst2 .^ 2);
len1 = real(sqrt(len1));
len2 = real(sqrt(len2));
Hst1 = Hst1 ./ (repmat(len1, d, 1) + eps);
Hst2 = Hst2 ./ (repmat(len2, d, 1) + eps);

ds = sum((Hst1 - Hst2) .^ 2) / 2;
ds = real(sqrt(ds));