function Ss = vdoSalCui(Fs)
% Computing video saliency.
%
% Reference
%   2010 - ECCV - Segmenting salient objects from images and Videos
%
% Input
%   Fs      -  video, 1 x nF (cell)
%   Vs      -  optical flow, 1 x nF (cell)
%
% Output
%   Ss      -  salience, h x w x nF
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 09-11-2013

% dimension
nF = length(Fs);
[h, w, ~] = size(Fs{1});

% function option
prIn('vdoSalCui', 'h %d, w %d, nF %d', h, w, nF);

% rgb to gray
[FGs, SXs, SYs] = zeross(h, w, nF);
for iF = 1 : nF
    FGs(:, :, iF) = im2double(rgb2gray(Fs{iF}));
end

% X-T
for i = 1 : h
    F = squeeze(FGs(i, :, :));
    S = imgSalSr(F);
    SXs(i, :, :) = reshape(S, [1 w nF]);
end

% Y-T
for i = 1 : w
    F = squeeze(FGs(:, i, :));
    S = imgSalSr(F);
    SYs(:, i, :) = reshape(S, [h 1 nF]);
end

% combine
Ss = SXs .* SYs;

% normalize
for iF = 1 : nF
    S = Ss(:, :, iF);
    Ss(:, :, iF) = S ./ max(S(:));
end

prOut;
