function Ss = vdoSalQt(Fs, Vs)
% Computing video saliency.
%
% Reference
%   2010 - ECCV - Segmenting salient objects from images and Videos
%
% Input
%   Fs      -  video, 1 x nF (cell)
%   Vs      -  optical flow, 1 x nF (cell)
%
% Output
%   Ss      -  salience, h x w x nF
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 09-09-2013

% dimension
nF = length(Fs);
[h, w, ~] = size(Fs{1});

% function option
prIn('vdoSalQt', 'h %d, w %d, nF %d', h, w, nF);

% parameter
saliency_map_resolution = [48 64];                    % the target saliency map resolution; the most important parameter for spectral saliency approaches
smap_smoothing_filter_params = {'gaussian', 9, 2.5};  % filter parameters for the final saliency map
cmap_smoothing_filter_params = {};                    % optionally, you can also smooth the conspicuity maps
cmap_normalization = 1;                               % specify the normalization of the conspicuity map here
extended_parameters = {};                             % @note: here you can specify advanced algorithm parameters for the selected algorithm, e.g. the quaternion axis
do_figures = false;                                   % enable/disable spectral_saliency_multichannel's integrated visualizations

Ss = zeros(h, w, nF);
prCIn('frame', nF, .1);
for iF = 1 : nF
    prC(iF);
    F = Fs{iF};
    V = Vs{iF};
    V = V ./ max(V(:));
    FD = im2double(F);
    X = zeros(h, w, 4);
    X(:, :, 1 : 3) = FD;
    X(:, :, 4) = V;

    %% main
    S = spectral_saliency_multichannel(X, ...
                                       saliency_map_resolution, ...
                                       'quat:dct', ...
                                       smap_smoothing_filter_params, ...
                                       cmap_smoothing_filter_params, ...
                                       cmap_normalization, ...
                                       extended_parameters, ...
                                       do_figures);

    %% resize
    S = imresize(S, [h, w]);
    S = S ./ max(S(:));
    Ss(:, :, iF) = S;
end
prCOut(nF);

prOut;
