function Ss = vdoSalRahtu(Fs, Vs)
% Computing video saliency.
%
% Reference
%   2010 - ECCV - Segmenting salient objects from images and Videos
%
% Input
%   Fs      -  video, 1 x nF (cell)
%   Vs      -  optical flow, 1 x nF (cell)
%
% Output
%   Ss      -  salience, h x w x nF
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 09-09-2013

% dimension
nF = length(Fs);
[h, w, ~] = size(Fs{1});

% function option
prIn('vdoSalRahtu', 'h %d, w %d, nF %d', h, w, nF);

Ss = zeros(h, w, nF);
prCIn('frame', nF, .1);
for iF = 1 : nF
    prC(iF);
    F = Fs{iF};
    V = Vs{iF};
    [L, a, b] = rgb2lab(F);
    Xs = {L, a, b, V};
    Ss(:, :, iF) = saliencyMeasure(Xs);
end
prCOut(nF);

prOut;
