function Ss = vdoSalSeo(Fs)
% Computing video saliency.
%
% Reference
%   2009 - JV - Static and space-time visual saliency detection by self-resemblance
%
% Input
%   Fs      -  video, 1 x nF (cell)
%
% Output
%   Ss      -  salience, h x w x nF
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 06-18-2013

% dimension
nF = length(Fs);
[h, w, ~] = size(Fs{1});

% function option
prIn('vdoSalSeo', 'h %d, w %d, nF %d', h, w, nF);

% convert
Y = zeros(h, w, nF);
for iF = 1 : nF
    F = Fs{iF};
    Y(:, :, iF) = double(rgb2gray(F));
end

% re-size
for i = 1 : nF
    Seq(:, :, i) = imresize(Y(:, :, i), [64 64], 'bilinear');
end
Seq = Seq / std(Seq(:));

% parameters
param.wsize = 3; % LARK spatial window size
param.wsize_t = 3; % LARK temporal window size
param.alpha = 0.42; % LARK sensitivity parameter
param.h = 1;  % smoothing parameter for LARK
param.sigma = 0.7; % fall-off parameter for self-resemblamnce

% compute 3-D LARKs
tic;
LARK = ThreeDLARK(Seq, param);
t = toc;
pr('3-D LARK computation %.0f secs', t);

% compute space-time saliency
tic;
SM = SpaceTimeSaliencyMap(Seq, LARK, param.wsize, param.wsize_t, param.sigma);
t = toc;
pr('SpaceTimeSaliencyMap %.f secs', t);

% re-store
Ss = zeros(h, w, nF);
for iF = 1 : nF
    Ss(:, :, iF) = imresize(SM(:, :, iF), [h w]);
end

% normalize
mi = min(Ss(:));
ma = max(Ss(:));
Ss = (Ss - mi) ./ (ma - mi);

prOut;
