function [SHstF, SHstM, SHstO, SPriS, SPriM, SPriB, SPriA] = vdoSalVox(hrVdo, hrFlow, wsSmp, wsFlow, wsAcc, wsBk, wsSeg, bins, wS, direS, sigS)
% Computing video saliency based on spatio-temporal voxels.
%
% Input
%   hrVdo   -  video input handle
%   wsSmp   -  sampling
%   wsFlow  -  flow
%   wsAcc   -  acceleration
%   wsBk    -  background
%   wsSeg   -  segmentation
%   bins    -  bins for quantatize appearance and flow, {[8 16 16 4 8 9]}
%   wS      -  window for cumulating histogram for computing saliency
%   direS   -  window type,  'both' | 'left' | 'right'
%   sigS    -  sigmod
%
% Output
%   SHstF   -  salience of apperance, mSeg x nF
%   SHstM   -  salience of magtitude, mSeg x nF
%   SHstO   -  salience of orientation, mSeg x nF
%   SPriS   -  salience of spatial prior, mSeg x nF
%   SPriM   -  salience of motion prior, mSeg x nF
%   SPriB   -  salience of background prior, mSeg x nF
%   SPriA   -  salience of acceleration, mSeg x nF
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 08-03-2013

if ~exist('sigS', 'var')
    sigS = 3;
end

% sampling
[nF, nF0, cFs] = stFld(wsSmp, 'nF', 'nF0', 'pFs');

% flow
magMas = stFld(wsFlow, 'magMas');

% acceleration
hrAcc = vdoRIn(wsAcc.vdo, 'comp', 'mat');
magMaAs = stFld(wsAcc, 'magMas');

% background
hrBk = vdoRIn(wsBk.vdo, 'comp', 'mat');

% segmentation
hrSeg = vdoRIn(wsSeg.vdo, 'comp', 'mat');
mSeg = stFld(wsSeg, 'mSeg');

% spatial prior
siz = stFld(hrSeg, 'siz');
[XD, YD] = computeRegionSpaXY(siz);

prIn('vdoSalVox', 'bins [%d %d %d %d %d %d], wS %d, direS %s', ...
     bins(1), bins(2), bins(3), bins(4), bins(5), bins(6), wS, direS);

% cache
[Ran0, RanC, idxC] = vdoCacheIdx(cFs, nF0, wS, direS);
[HstFs, HstMs, HstOs, areass, xDss, yDss, Ls, magss, magAss, bkss] = cellss(1, wS);
iF = 1;

% loop the video
[SHstF, SHstM, SHstO, SPriS, SPriM, SPriB, SPriA] = zeross(mSeg, nF);
prCIn('frame', nF0, .1);
for pF = 1 : nF0
    prC(pF);

    %% useless frame, skip
    iC = idxC(pF);
    if iC < 0
        continue;
    end

    %% read frame
    [HstFs{iC}, HstMs{iC}, HstOs{iC}, areass{iC}, xDss{iC}, yDss{iC}, L, magss{iC}, magAss{iC}, bkss{iC}] ...
        = vdoSalVoxHst(hrVdo, hrFlow, hrAcc, hrBk, hrSeg, pF, mSeg, bins, XD, YD, magMas(pF), magMaAs(pF));

    %% the end of this window, compute the cumulative score
    while iF <= nF && pF == Ran0(2, iF)
        head = RanC(1, iF);
        tail = RanC(2, iF);
        cen = RanC(3, iF);

        %% weight
        indC = circleIdx(head, tail, wS);
        dsts = (Ran0(1, iF) : Ran0(2, iF)) - Ran0(3, iF);
        ws = dst2Gauss(abs(dsts), sigS, wS);
        % ws(:) = 1;

        %% adjacency
        % A = vdoSegL2A(L, mSeg);

        %% core alg
        % [SHstF(:, iF), SHstM(:, iF), SHstO(:, iF), SPriS(:, iF), SPriM(:, iF), SPriB(:, iF), SPriA(:, iF)] ...
        %     = vdoSalVoxSal(HstFs, HstMs, HstOs, areass, xDss, yDss, magss, magAss, bkss, indC, ws, A, siz);

        %% core alg
        [SHstF(:, iF), SHstM(:, iF), SHstO(:, iF), SPriS(:, iF), SPriM(:, iF), SPriB(:, iF), SPriA(:, iF)] ...
            = vdoSalVoxSal2(HstFs, HstMs, HstOs, areass, xDss, yDss, magss, magAss, bkss, indC, ws, L, siz, mSeg);

        % if iF == 149 && 1
        %     disp('here');
        % end

        iF = iF + 1;
    end
end
prCOut(nF0);

prOut;
