function [sHstFs, sHstMs, sHstOs, sPriSs, sPriMs, sPriBs, sPriAs] = vdoSalVoxSal(HstFs, HstMs, HstOs, areass, xDss, yDss, magss, magAss, bkss, indC, ws, A, siz)
% Computing video saliency based on spatio-temporal voxels.
%
% Input
%   Fs      -  frame, 1 x wF (cell)
%   VXs     -  flow, 1 x wF (cell)
%   VYs     -  flow, 1 x wF (cell)
%   Ms      -  flow, 1 x wF (cell)
%   MAs     -  flow, 1 x wF (cell)
%   Ls      -  label, 1 x wF (cell)
%   Ps      -  background, 1 x wF (cell)
%   XD      -  foreground, h x w
%   YD      -  foreground, h x w
%   ws      -  weight, 1 x wF
%   bins    -  bins for quantatize appearance and flow, {[8 16 16 4 8 9]}
%   mSeg    -  #segments
%
% Output
%   sHstFs  -  salience of apperance, mSeg x 1
%   sHstMs  -  salience of magtitude, mSeg x 1
%   sHstOs  -  salience of orientation, mSeg x 1
%   sPriSs  -  salience of spatial prior, mSeg x 1
%   sPriMs  -  salience of motion prior, mSeg x 1
%   sPriBs  -  salience of background prior, mSeg x 1
%   sPriAs  -  salience of acceleration, mSeg x 1
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-23-2013

% dimension
wF = length(ws);
prIn('vdoSalVoxSal');

% re-compute the neightbor
for iF = 1 : wF
    iC = indC(iF);
    w = ws(iF);

    HstFi = HstFs{iC} * w;
    HstMi = HstMs{iC} * w;
    HstOi = HstOs{iC} * w;
    areasi = areass{iC} * w;
    xDsi = xDss{iC} * w;
    yDsi = yDss{iC} * w;
    magsi = magss{iC} * w;
    magAsi = magAss{iC} * w;
    bksi = bkss{iC} * w;

    if iF == 1
        HstF = HstFi;
        HstM = HstMi;
        HstO = HstOi;
        areas = areasi;
        xDs = xDsi;
        yDs = yDsi;
        mags = magsi;
        magAs = magAsi;
        bks = bksi;
    else
        HstF = HstF + HstFi;
        HstM = HstM + HstMi;
        HstO = HstO + HstOi;
        areas = areas + areasi;
        xDs = xDs + xDsi;
        yDs = yDs + yDsi;
        mags = mags + magsi;
        magAs = magAs + magAsi;
        bks = bks + bksi;
    end
end

% histogram distance
idx = find(areas == 0);
DF = computeHistDist(sparse(HstF), A, idx);
DM = computeHistDist(sparse(HstM), A, idx);
DO = computeHistDist(sparse(HstO), A, idx);

% histogram saliency
sHstFs = computeSalHst(DF, A, areas, siz);
sHstMs = computeSalHst(DM, A, areas, siz);
sHstOs = computeSalHst(DO, A, areas, siz);

% spatial prior saliency
sPriSs = computeSalPriSpa(areas, xDs, yDs, siz);
sPriMs = computeSalPriMag(areas, mags);
sPriAs = computeSalPriMag(areas, magAs);
sPriBs = computeSalPriMag(areas, bks);

prOut;