function [sHstFs, sHstMs, sHstOs, sPriSs, sPriMs, sPriBs, sPriAs] = vdoSalVoxSal2(HstFs, HstMs, HstOs, areass, xDss, yDss, magss, magAss, bkss, indC, ws, L, siz, mSeg)
% Computing video saliency based on spatio-temporal voxels.
%
% Input
%   Fs      -  frame, 1 x wF (cell)
%   VXs     -  flow, 1 x wF (cell)
%   VYs     -  flow, 1 x wF (cell)
%   Ms      -  flow, 1 x wF (cell)
%   MAs     -  flow, 1 x wF (cell)
%   Ls      -  label, 1 x wF (cell)
%   Ps      -  background, 1 x wF (cell)
%   XD      -  foreground, h x w
%   YD      -  foreground, h x w
%   ws      -  weight, 1 x wF
%   bins    -  bins for quantatize appearance and flow, {[8 16 16 4 8 9]}
%   mSeg    -  #segments
%
% Output
%   sHstFs  -  salience of apperance, mSeg x 1
%   sHstMs  -  salience of magtitude, mSeg x 1
%   sHstOs  -  salience of orientation, mSeg x 1
%   sPriSs  -  salience of spatial prior, mSeg x 1
%   sPriMs  -  salience of motion prior, mSeg x 1
%   sPriBs  -  salience of background prior, mSeg x 1
%   sPriAs  -  salience of acceleration, mSeg x 1
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 01-03-2009
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-27-2013

% dimension
wF = length(ws);
prIn('vdoSalVoxSal2');

% re-compute the neightbor
for iF = 1 : wF
    iC = indC(iF);
    w = ws(iF);

    if w == 1
        HstFi = HstFs{iC};
        HstMi = HstMs{iC};
        HstOi = HstOs{iC};
        areasi = areass{iC};
        xDsi = xDss{iC};
        yDsi = yDss{iC};
        magsi = magss{iC};
        magAsi = magAss{iC};
        bksi = bkss{iC};
    else
        HstFi = HstFs{iC} * w;
        HstMi = HstMs{iC} * w;
        HstOi = HstOs{iC} * w;
        areasi = areass{iC} * w;
        xDsi = xDss{iC} * w;
        yDsi = yDss{iC} * w;
        magsi = magss{iC} * w;
        magAsi = magAss{iC} * w;
        bksi = bkss{iC} * w;
    end

    if iF == 1
        HstF = HstFi;
        HstM = HstMi;
        HstO = HstOi;
        areas = areasi;
        xDs = xDsi;
        yDs = yDsi;
        mags = magsi;
        magAs = magAsi;
        bks = bksi;
    else
        HstF = HstF + HstFi;
        HstM = HstM + HstMi;
        HstO = HstO + HstOi;
        areas = areas + areasi;
        xDs = xDs + xDsi;
        yDs = yDs + yDsi;
        mags = mags + magsi;
        magAs = magAs + magAsi;
        bks = bks + bksi;
    end
end

% histogram distance
vis = areas > 0;

% center
[~, xCens, yCens] = maskRegCen(uint16(L), mSeg);

% center distance
Cens = [xCens / siz(2); yCens / siz(1)];
A = exp(-conDst(Cens, Cens) / 0.04);

A = A(vis, vis);
areas = areas(vis);
xDs = xDs(vis);
yDs = yDs(vis);
mags = mags(vis);
magAs = magAs(vis);
bks = bks(vis);

DF = computeHistDist3(HstF(vis, :)');
DM = computeHistDist3(HstM(vis, :)');
DO = computeHistDist3(HstO(vis, :)');

sHstF1s = computeSalHst2(DF, A, areas, siz);
sHstM1s = computeSalHst2(DM, A, areas, siz);
sHstO1s = computeSalHst2(DO, A, areas, siz);

sPriS1s = computeSalPriSpa(areas, xDs, yDs, siz);
sPriM1s = computeSalPriMag(areas, mags);
sPriA1s = computeSalPriMag(areas, magAs);
sPriB1s = computeSalPriMag(areas, bks);

[sHstFs, sHstMs, sHstOs, sPriSs, sPriMs, sPriAs, sPriBs] = zeross(mSeg, 1);
sHstFs(vis) = sHstF1s;
sHstMs(vis) = sHstM1s;
sHstOs(vis) = sHstO1s;
sPriSs(vis) = sPriS1s;
sPriMs(vis) = sPriM1s;
sPriAs(vis) = sPriA1s;
sPriBs(vis) = sPriB1s;

prOut;