function F = imgHsvM(F0, cl, M)
% Segmenting the image to super-pixels.
%
% Input
%   F       -  image, h x w x nChan (double)
%   parSeg
%     alg   -  #algorithm, {'slic'} | 'ucb'
%                 slic: SLIC algorithm based on vlfeat
%                 ucb:  UC Berkeley's method
%     sca   -  resize scale, {1}
%     v1    -  value 1, {0}
%     v2    -  value 2, {0}
%     v3    -  value 3, {0}
%
% Output
%   M       -  segmentation mask
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 07-09-2012
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-24-2013

if strcmp(cl, 'hsv')
    F = F0;
    return;
end

Hsv = rgb2hsv(F0);
H = Hsv(:, :, 1);
S = Hsv(:, :, 2);
V = Hsv(:, :, 3);

if strcmp(cl, 'msv')
    F = hsv2rgb(M, S, V);
elseif strcmp(cl, 'hmv')
    F = hsv2rgb(H, M, V);
elseif strcmp(cl, 'hsm')
    F = hsv2rgb(H, S, M * .2 + V * .8);
else
    error('unknown cl: %s', cl);
end

% output
F = min(1, F);
F = max(0, F);
F = uint8(F * 255);