function F = imgLabM(F0, cl, M)
% Segmenting the image to super-pixels.
%
% Input
%   F       -  image, h x w x nChan (double)
%   parSeg
%     alg   -  #algorithm, {'slic'} | 'ucb'
%                 slic: SLIC algorithm based on vlfeat
%                 ucb:  UC Berkeley's method
%     sca   -  resize scale, {1}
%     v1    -  value 1, {0}
%     v2    -  value 2, {0}
%     v3    -  value 3, {0}
%
% Output
%   M       -  segmentation mask
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 07-09-2012
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-25-2013

if strcmp(cl, 'lab')
    F = F0;
    return;
end

Lab = rgb2lab(F0);
L = Lab(:, :, 1);
A = Lab(:, :, 2);
B = Lab(:, :, 3);

M = M * 3;

if strcmp(cl, 'mab')
    L = M * 100 * .5 + double(L) * .5;
    F = lab2rgb(L, A, B);
elseif strcmp(cl, 'lmb')
    A = M * 240 - 120;
    F = lab2rgb(L, A, B);
elseif strcmp(cl, 'lam')
    B = M * 240 - 120;
    F = lab2rgb(L, A, B);
else
    error('unknown cl: %s', cl);
end
