function D = maskRegDst(IdxL2R, coRs, xCens, yCens, idxR2L0, xCen0s, yCen0s)
% Compute the relative distance.
%
% Input
%   IdxL2R   -  label id -> region id, mL x coRMa
%   coRs     -  #region for each label, 1 x mR
%   xCens    -  center x of each region, 1 x mR
%   yCens    -  center y of each region, 1 x mR
%   idxR2L0  -  region id -> label id, 1 x mR0
%   xCen0s   -  center x of each region, 1 x mR0
%   yCen0s   -  center y of each region, 1 x mR0
%
% Output
%   D        -  distance, mR0 x coRMa
%
% History
%   create   -  Feng Zhou (zhfe99@gmail.com), 11-08-2010
%   modify   -  Feng Zhou (zhfe99@gmail.com), 07-12-2013

% dimension
mR0 = length(xCen0s);
coRMa = max(coRs);

% center distance
D = zeros(mR0, coRMa);
for cR0 = 1 : mR0
    %% region with the same label
    l = idxR2L0(cR0);
    coRc = coRs(l);
    cRs = IdxL2R(l, 1 : coRc);

    %% distance
    D(cR0, 1 : coRc) = real(sqrt((xCen0s(cR0) - xCens(cRs)) .^ 2 + (yCen0s(cR0) - yCens(cRs)) .^ 2));
end
