function [D, idxRMa, Dst, Siz, coRs, IdxL2R, xCens, yCens, R] = maskRegMax(L, mL)
% Maximum region mask.
%
% Input
%   L       -  label matrix, h x w (uint16)
%   mL      -  #label
%
% Output
%   D       -  distance
%   idxRMa  -  index of largest region, 1 x mL
%   D       -  distance, mR x coRMa
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 11-08-2010
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-23-2013

% find the connected region
[R, mR, coRs] = maskRegConn(L, mL);
coRMa = max(coRs);

% region stat
[idxR2L, IdxL2R, idxR2O, sizs, xCens, yCens] = maskRegStat(L, R, mL, mR, coRMa);

% region size
Siz = zeros(mL, coRMa);
idx = find(IdxL2R ~= 0);
Siz(idx) = sizs(IdxL2R(idx));

% maximum region
[~, idx1] = max(Siz, [], 2);
idx2 = sub2ind([mL, coRMa], 1 : mL, idx1');
idxRMa = IdxL2R(idx2)';

% region status
vis = ones(1, mR);
vis(idxRMa(idxRMa > 0)) = 0;
S0 = vis(R);

% distance
Dst = zeros(mL, coRMa);
ds = zeros(1, mR);
for cL = 1 : mL
    coRc = coRs(cL);
    if coRc == 0
        continue;
    end

    p = idxRMa(cL);
    cRs = IdxL2R(cL, 1 : coRc);
    Dst(cL, 1 : coRc) = real(sqrt((xCens(p) - xCens(cRs)) .^ 2 + (yCens(p) - yCens(cRs)) .^ 2));
    ds(cRs) = Dst(cL, 1 : coRc);
end
D = ds(R);
D = single(D / max(size(L)));
