function wsReg = maskRegProp(L, mL)
% Split mask to disjoint regions of the 1st frame.
%
% Input
%   L         -  label matrix, h x w (uint16)
%   mL        -  #label
%
% Output
%   wsReg
%     R       -  region matrix, h x w (uint16)
%     mR      -  #region
%     coRMa   -  maximum #region for each label
%     coRs    -  #region for each label, 1 x mL
%     idxR2L  -  region id -> label id, 1 x mR
%     IdxL2R  -  label id -> region id, mL x mRMa
%     idxR2T  -  region id -> label count, 1 x mR
%     sizs    -  region size, 1 x mR
%     xCens   -  center x of each region, 1 x mR
%     yCens   -  center y of each region, 1 x mR
%
% History
%   create    -  Feng Zhou (zhfe99@gmail.com), 07-08-2013
%   modify    -  Feng Zhou (zhfe99@gmail.com), 07-23-2013

% dis-connected region
[R, mR, coRs] = maskRegConn(L, mL);
coRMa = max(coRs);

% region stat
[idxR2L, IdxL2R, idxR2T, sizs, xCens, yCens] = maskRegStat(L, R, mL, mR, coRMa);

% store
wsReg.R = R;
wsReg.mR = mR;
wsReg.coRs = coRs;
wsReg.coRMa = coRMa;
wsReg.idxR2L = idxR2L;
wsReg.IdxL2R = IdxL2R;
wsReg.idxR2T = idxR2T;
wsReg.sizs = sizs;
wsReg.xCens = xCens;
wsReg.yCens = yCens;