function [Ss, mS] = maskRegSplit(Ls, mL, wsRegs)
% Split mask to disjoint regions of the 1st frame.
%
% Input
%   Ls      -  label matrix, 1 x nF (cell), h x w (uint16)
%   mL      -  #label
%   wsRegs  -  region, 1 x nF (cell)
%
% Output
%   Ss      -  region matrix, 1 x nF (cell), h x w (uint16)
%   mS      -  #label after split
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 11-08-2010
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-23-2013

% dimension
nF = length(Ls);

% each frame
Ss = cellss(1, nF);
prCIn('split', nF, .3);
for iF = 1 : nF
    prC(iF);

    %% info
    L = Ls{iF};
    wsReg = wsRegs{iF};

    %% split
    if iF == 1
        [R, ss, mS] = maskRegSplitInit(wsReg);
    else
        [R, ss, mS] = maskRegSplitNext(wsReg, wsReg0, s0s, mS0);
    end

    %% restore
    Ss{iF} = ss(R);

    %% store
    wsReg0 = wsReg;
    s0s = ss;
    mS0 = mS;
end
prCOut(nF);