function wsSeg = hsSegLSplit(src, wsSeg0, varargin)
% Merge the super-voxels.
%
% Input
%   src     -  hs src
%   wsSeg0  -  segmentation
%   varargin
%     save option
%
% Output
%   wsSeg   -  segmentation result
%     mSeg  -  #segments
%     keys  -  color key, mSeg x 1
%     A     -  adjacency matrix, mSeg x mSeg
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 05-23-2013
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-12-2013

% save option
prex = wsSeg0.prex;
[svL, path] = psSv(varargin, ...
                   'prex', prex, ...
                   'subx', 'split', ...
                   'fold', 'hs/seg');

% load
if svL == 2 && exist(path, 'file')
    prInOut('hsSegSplit', 'old, %s', prex);
    wsSeg = matFld(path, 'wsSeg');
    return;
end
prIn('hsSegSplit', 'new, %s', prex);

% dimension
[Ls, mSeg] = stFld(wsSeg0, 'Ls', 'mSeg');
[h, w, nF] = size(Ls);

% save each frame
prCIn('frame', nF, .1);
mSs = zeros(1, nF);
Ss = zeros(h, w, nF, 'uint16');
for iF = 1 : nF
    prC(iF);
    L = Ls(:, :, iF);

    %% split
    if iF == 1
        [R, ss, mS, coRs, idxR2L, IdxL2R, idxR2T, xCens, yCens] = maskRegSplitInit(L, mSeg);
    else
        [R, ss, mS, coRs, idxR2L, IdxL2R, idxR2T, xCens, yCens] = maskRegSplit(L, mSeg, R0, s0s, mS0, idxR2L0, IdxL2R0, idxR2T0, xCen0s, yCen0s);
    end

    %% pixel label
    Ss(:, :, iF) = uint16(ss(R));

    %% save for next frame
    s0s = ss;
    mS0 = mS;
    idxR2L0 = idxR2L;
    IdxL2R0 = IdxL2R;
    idxR2T0 = idxR2T;
    xCen0s = xCens;
    yCen0s = yCens;
    R0 = R;
    mSs(iF) = mS;
end
prCOut(nF);

% adjaceny matrix
A = vdoSegL2A(Ss, mS);

% store
wsSeg.prex = prex;
wsSeg.Ls = Ss;
wsSeg.mSeg = mS;
wsSeg.A = A;
wsSeg.keys = wsSeg0.keys;

% save
if svL > 0
    save(path, 'wsSeg');
end

prOut;