function [Ls, mSeg, keys] = vdoSegM2L(hr, parSeg)
% Convert image-based label to video-based label.
%
% Input
%   hr      -  segmentation input handle
%   parSeg  -  segmentation parameter
%
% Output
%   Ls      -  segment label, h x w x nF
%   mSeg    -  #segments
%   keys    -  color key, mSeg x 1
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 05-23-2013
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-06-2013

% dimension
[nF, siz] = stFld(hr, 'nF', 'siz');
h = siz(1);
w = siz(2);
prIn('vdoSegM2L', 'nF %d, siz [%d %d]', nF, h, w);

% parameter
mMa = 10000; % maximum #segments
keys = zeros(1, mMa);
idxA = [];
mSegA = 0;
mSeg = 0;

% label matrix
Ls = zeros(siz(1), siz(2), nF, 'uint16');
css = cellss(1, nF);
prCIn('frame', nF, .1);
for iF = 1 : nF
    prC(iF);

    %% read
    M = double(vdoR(hr, iF));
    M0 = M;

    %% remap
    M = M(:, :, 1) + M(:, :, 2) * 256 + M(:, :, 3) * 256 ^ 2;
    [gid, ~, gl] = grp2idx(M(:));
    mi = length(gl);

    % M00 = imgKey2Cl(M);
    % equal('M0', M00, M0);

    %% merge with previous frame
    p = zeros(1, mi);
    visA = zeros(1, mSegA);
    idxAN = [];
    gid0 = gid;
    for c = 1 : mi
        isF = 0;
        for cA = 1 : mSegA
            if gl(c) == keys(idxA(cA))
                isF = 1;
                break;
            end
        end

        if isF == 1
            p(c) = idxA(cA);
            visA(cA) = 1;
        else
            mSeg = mSeg + 1;
            keys(mSeg) = gl(c);
            p(c) = mSeg;
            idxAN = [idxAN, mSeg];
        end
        gid(gid0 == c) = p(c);
    end
    Ls(:, :, iF) = uint16(reshape(gid, [h, w]));

    %% update the active segment
    idxA = [idxA(visA == 1), idxAN];
    mSegA = length(idxA);
end
prCOut(nF);
keys(mSeg + 1 : end) = [];

prOut;
