function [Ls, A] = vdoSegMerge(L0s, A0, AD)
% Convert video-based segmentation to an adjacency matrix.
%
% Input
%   L0s     -  original super-voxel label, h x w x nF
%   A0      -  original adjacency matrix, mSeg0 x mSeg0
%   AD      -  connected adjacency matrix, mSeg0 x mSeg0
%   keys    -  original color key, mSeg0 x 1
%
% Output
%   Ls      -  new super-voxel label, h x w x nF
%   A       -  new adjacency matrix, mSeg x mSeg
%   keys    -  new color key, mSeg x 1
%
% History
%   create  -  Feng Zhou (zhfe99@gmail.com), 05-23-2013
%   modify  -  Feng Zhou (zhfe99@gmail.com), 07-06-2013

% dimension
[h, w, nF] = size(L0s);
mSeg0 = size(A0, 1);
prIn('vdoSegMerge', 'nF %d, siz [%d %d], mSeg0 %d', nF, h, w, mSeg0);

% new label
ind = find(AD);
labels = mexMergeAdjacentRegions(double(AD), ind - 1);
ind = find(labels == 0);
labels(ind) = max(labels(:)) + [1 : length(ind)];
mSeg = max(labels(:));

% adjust label
Ls = L0s;
prCIn('adjust label', nF, .1);
for iF = 1 : nF
    prC(iF);
    L0 = double(L0s(:, :, iF));
    L = relabel_L_fast(L0, labels);
    Ls(:, :, iF) = uint16(L);
end
prCOut(nF);

% adjaceny matrix
A = vdoSegL2A(Ls, mSeg);

prOut;
